@@ -27,13 +27,13 @@ def triangular_kernel(u: np.ndarray) -> np.ndarray:
 
 def gaussian_kernel(u: np.ndarray) -> np.ndarray:
     """Calculate gaussian kernel function."""
-    return np.exp(-(u ** 2) / 2) / np.sqrt(2 * np.pi)
+    return np.exp(-(u**2) / 2) / np.sqrt(2 * np.pi)
 
 
 def epanechnikov_kernel(u: np.ndarray) -> np.ndarray:
     """Calculate epanechnikov kernel function."""
     clipped_u = np.clip(u, -1.0, 1.0)
-    return 0.75 * (1 - clipped_u ** 2)
+    return 0.75 * (1 - clipped_u**2)
 
 
 def cosine_kernel(u: np.ndarray) -> np.ndarray:
@@ -66,7 +66,7 @@ class BaseContinuousOffPolicyEstimator(metaclass=ABCMeta):
 
     @abstractmethod
     def estimate_interval(self) -> Dict[str, float]:
-        """Estimate the confidence interval of the policy value using nonparametric bootstrap."""
+        """Estimate the confidence interval of the policy value using bootstrap."""
         raise NotImplementedError
 
 
@@ -225,7 +225,7 @@ class KernelizedInverseProbabilityWeighting(BaseContinuousOffPolicyEstimator):
         random_state: Optional[int] = None,
         **kwargs,
     ) -> Dict[str, float]:
-        """Estimate the confidence interval of the policy value using nonparametric bootstrap.
+        """Estimate the confidence interval of the policy value using bootstrap.
 
         Parameters
         ----------
@@ -451,7 +451,7 @@ class KernelizedSelfNormalizedInverseProbabilityWeighting(
         random_state: Optional[int] = None,
         **kwargs,
     ) -> Dict[str, float]:
-        """Estimate the confidence interval of the policy value using nonparametric bootstrap.
+        """Estimate the confidence interval of the policy value using bootstrap.
 
         Parameters
         ----------
@@ -687,7 +687,7 @@ class KernelizedDoublyRobust(BaseContinuousOffPolicyEstimator):
         random_state: Optional[int] = None,
         **kwargs,
     ) -> Dict[str, float]:
-        """Estimate the confidence interval of the policy value using nonparametric bootstrap.
+        """Estimate the confidence interval of the policy value using bootstrap.
 
         Parameters
         ----------
