@@ -136,10 +136,19 @@ class ContinuousOffPolicyEvaluation:
                     raise ValueError(
                         f"Expected `estimated_rewards_by_reg_model[{estimator_name}].shape == action_by_evaluation_policy.shape`, but found it False"
                     )
-        elif estimated_rewards_by_reg_model.shape != action_by_evaluation_policy.shape:
-            raise ValueError(
-                "Expected `estimated_rewards_by_reg_model.shape == action_by_evaluation_policy.shape`, but found it False"
+        else:
+            check_array(
+                array=estimated_rewards_by_reg_model,
+                name="estimated_rewards_by_reg_model",
+                expected_dim=1,
             )
+            if (
+                estimated_rewards_by_reg_model.shape
+                != action_by_evaluation_policy.shape
+            ):
+                raise ValueError(
+                    "Expected `estimated_rewards_by_reg_model.shape == action_by_evaluation_policy.shape`, but found it False"
+                )
         estimator_inputs = {
             estimator_name: {
                 input_: self.bandit_feedback[input_]
@@ -222,7 +231,7 @@ class ContinuousOffPolicyEvaluation:
         n_bootstrap_samples: int = 100,
         random_state: Optional[int] = None,
     ) -> Dict[str, Dict[str, float]]:
-        """Estimate confidence intervals of policy values using nonparametric bootstrap.
+        """Estimate confidence intervals of policy values using bootstrap.
 
         Parameters
         ------------
@@ -611,7 +620,7 @@ class ContinuousOffPolicyEvaluation:
         """
         if len(policy_name_list) != len(action_by_evaluation_policy_list):
             raise ValueError(
-                "the length of policy_name_list must be the same as action_by_evaluation_policy_list"
+                "the length of `policy_name_list` must be the same as action_by_evaluation_policy_list"
             )
         if fig_dir is not None:
             assert isinstance(fig_dir, Path), "`fig_dir` must be a Path"
