@@ -54,11 +54,11 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
         Output space of the neural network policy.
 
     hidden_layer_size: Tuple[int, ...], default = (100,)
-        The i th element specifies the size of the i th layer.
+        The i-th element specifies the size of the i-th layer.
 
     activation: str, default='relu'
         Activation function.
-        Must be one of the following:
+        Must be one of the followings:
         - 'identity', the identity function, :math:`f(x) = x`.
         - 'logistic', the sigmoid function, :math:`f(x) = \\frac{1}{1 + \\exp(x)}`.
         - 'tanh', the hyperbolic tangent function, `:math:f(x) = \\frac{\\exp(x) - \\exp(-x)}{\\exp(x) + \\exp(-x)}`
@@ -66,7 +66,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
 
     solver: str, default='adam'
         Optimizer of the neural network.
-        Must be one of the following:
+        Must be one of the followings:
         - 'sgd', Stochastic Gradient Descent.
         - 'adam', Adam (Kingma and Ba 2014).
         - 'adagrad', Adagrad (Duchi et al. 2011).
@@ -198,12 +198,12 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             [not isinstance(h, int) or h <= 0 for h in self.hidden_layer_size]
         ):
             raise ValueError(
-                f"hidden_layer_size must be tuple of positive integers, but {self.hidden_layer_size} is given"
+                f"`hidden_layer_size` must be a tuple of positive integers, but {self.hidden_layer_size} is given"
             )
 
         if self.solver not in ("adagrad", "sgd", "adam"):
             raise ValueError(
-                f"solver must be one of 'adam', 'adagrad', or 'sgd', but {self.solver} is given"
+                f"`solver` must be one of 'adam', 'adagrad', or 'sgd', but {self.solver} is given"
             )
 
         check_scalar(self.alpha, "alpha", float, min_val=0.0)
@@ -212,7 +212,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             not isinstance(self.batch_size, int) or self.batch_size <= 0
         ):
             raise ValueError(
-                f"batch_size must be a positive integer or 'auto', but {self.batch_size} is given"
+                f"`batch_size` must be a positive integer or 'auto', but {self.batch_size} is given"
             )
 
         check_scalar(self.learning_rate_init, "learning_rate_init", float)
@@ -224,7 +224,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
         check_scalar(self.max_iter, "max_iter", int, min_val=1)
 
         if not isinstance(self.shuffle, bool):
-            raise ValueError(f"shuffle must be a bool, but {self.shuffle} is given")
+            raise ValueError(f"`shuffle` must be a bool, but {self.shuffle} is given")
 
         check_scalar(self.tol, "tol", float)
         if self.tol <= 0.0:
@@ -234,12 +234,12 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
 
         if not isinstance(self.nesterovs_momentum, bool):
             raise ValueError(
-                f"nesterovs_momentum must be a bool, but {self.nesterovs_momentum} is given"
+                f"`nesterovs_momentum` must be a bool, but {self.nesterovs_momentum} is given"
             )
 
         if not isinstance(self.early_stopping, bool):
             raise ValueError(
-                f"early_stopping must be a bool, but {self.early_stopping} is given"
+                f"`early_stopping` must be a bool, but {self.early_stopping} is given"
             )
 
         check_scalar(
@@ -258,7 +258,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
         if self.q_func_estimator_hyperparams is not None:
             if not isinstance(self.q_func_estimator_hyperparams, dict):
                 raise ValueError(
-                    "q_func_estimator_hyperparams must be a dict"
+                    "`q_func_estimator_hyperparams` must be a dict"
                     f", but {type(self.q_func_estimator_hyperparams)} is given"
                 )
 
@@ -278,7 +278,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             activation_layer = nn.ELU
         else:
             raise ValueError(
-                "activation must be one of 'identity', 'logistic', 'tanh', 'relu', or 'elu'"
+                "`activation` must be one of 'identity', 'logistic', 'tanh', 'relu', or 'elu'"
             )
 
         layer_list = []
@@ -318,7 +318,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             Context vectors observed for each data, i.e., :math:`x_i`.
 
         action: array-like, shape (n_rounds,)
-            Continuous action values sampled by a behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
+            Continuous action values sampled by the logging/behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
         reward: array-like, shape (n_rounds,)
             Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
@@ -337,7 +337,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
         elif isinstance(self.batch_size, int) and self.batch_size > 0:
             batch_size_ = self.batch_size
         else:
-            raise ValueError("batch_size must be a positive integer or 'auto'")
+            raise ValueError("`batch_size` must be a positive integer or 'auto'")
 
         dataset = NNPolicyDatasetForContinuousAction(
             torch.from_numpy(context).float(),
@@ -402,7 +402,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             Context vectors observed for each data, i.e., :math:`x_i`.
 
         action: array-like, shape (n_rounds,)
-            Continuous action values sampled by a behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
+            Continuous action values sampled by the logging/behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
         reward: array-like, shape (n_rounds,)
             Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
@@ -458,7 +458,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             )
         else:
             raise NotImplementedError(
-                "solver must be one of 'adam', 'adagrad', or 'sgd'"
+                "`solver` must be one of 'adam', 'adagrad', or 'sgd'"
             )
 
         training_data_loader, validation_data_loader = self._create_train_data_for_opl(
@@ -478,19 +478,15 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             for x, a, r, p in training_data_loader:
                 optimizer.zero_grad()
                 action_by_current_policy = self.nn_model(x).flatten()
-                loss = (
-                    -1.0
-                    * self._estimate_policy_value(
-                        context=x,
-                        reward=r,
-                        action=a,
-                        pscore=p,
-                        action_by_current_policy=action_by_current_policy,
-                    ).mean()
-                )
+                loss = -self._estimate_policy_gradient(
+                    context=x,
+                    reward=r,
+                    action=a,
+                    pscore=p,
+                    action_by_current_policy=action_by_current_policy,
+                ).mean()
                 loss.backward()
                 optimizer.step()
-
                 loss_value = loss.item()
                 if previous_training_loss is not None:
                     if loss_value - previous_training_loss < self.tol:
@@ -505,16 +501,13 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
                 self.nn_model.eval()
                 for x, a, r, p in validation_data_loader:
                     action_by_current_policy = self.nn_model(x).flatten()
-                    loss = (
-                        -1.0
-                        * self._estimate_policy_value(
-                            context=x,
-                            reward=r,
-                            action=a,
-                            pscore=p,
-                            action_by_current_policy=action_by_current_policy,
-                        ).mean()
-                    )
+                    loss = -self._estimate_policy_gradient(
+                        context=x,
+                        reward=r,
+                        action=a,
+                        pscore=p,
+                        action_by_current_policy=action_by_current_policy,
+                    ).mean()
                     loss_value = loss.item()
                     self.val_loss_curve.append(-loss_value)
                     if previous_validation_loss is not None:
@@ -526,7 +519,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
                         break
                     previous_validation_loss = loss_value
 
-    def _estimate_policy_value(
+    def _estimate_policy_gradient(
         self,
         context: torch.Tensor,
         action: torch.Tensor,
@@ -534,7 +527,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
         pscore: torch.Tensor,
         action_by_current_policy: torch.Tensor,
     ) -> float:
-        """Calculate policy loss used in the policy gradient method.
+        """Estimate the policy gradient.
 
         Parameters
         -----------
@@ -542,26 +535,26 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             Context vectors observed for each data, i.e., :math:`x_i`.
 
         action: Tensor, shape (batch_size,)
-            Continuous action values sampled by a behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
+            Continuous action values sampled by the logging/behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
         reward: Tensor, shape (batch_size,)
             Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
 
         pscore: Tensor, shape (batch_size,)
-            Action choice probabilities of behavior policy (generalized propensity scores), i.e., :math:`\\pi_b(a_i|x_i)`.
+            Action choice probabilities of the logging/behavior policy (generalized propensity scores), i.e., :math:`\\pi_b(a_i|x_i)`.
 
         action_by_current_policy: Tensor, shape (batch_size,)
             Continuous action values given by the current policy.
 
         Returns
         ----------
-        estimated_policy_value_arr: array-like, shape (batch_size,)
+        estimated_policy_grad_arr: array-like, shape (batch_size,)
             Rewards of each data estimated by an OPE estimator.
 
         """
 
         def gaussian_kernel(u: torch.Tensor) -> torch.Tensor:
-            return torch.exp(-(u ** 2) / 2) / ((2 * np.pi) ** 0.5)
+            return torch.exp(-(u**2) / 2) / ((2 * np.pi) ** 0.5)
 
         if self.output_space is not None:
             action_by_current_policy = torch.clamp(
@@ -571,7 +564,7 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
             )
 
         if self.pg_method == "dpg":
-            estimated_policy_value_arr = self.q_func_estimator.predict(
+            estimated_policy_grad_arr = self.q_func_estimator.predict(
                 context=context,
                 action=action_by_current_policy,
             )
@@ -579,8 +572,8 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
         elif self.pg_method == "ipw":
             u = action_by_current_policy - action
             u /= self.bandwidth
-            estimated_policy_value_arr = gaussian_kernel(u) * reward / pscore
-            estimated_policy_value_arr /= self.bandwidth
+            estimated_policy_grad_arr = gaussian_kernel(u) * reward / pscore
+            estimated_policy_grad_arr /= self.bandwidth
 
         elif self.pg_method == "dr":
             u = action_by_current_policy - action
@@ -589,11 +582,11 @@ class ContinuousNNPolicyLearner(BaseContinuousOfflinePolicyLearner):
                 context=context,
                 action=action_by_current_policy,
             )
-            estimated_policy_value_arr = gaussian_kernel(u) * (reward - q_hat) / pscore
-            estimated_policy_value_arr /= self.bandwidth
-            estimated_policy_value_arr += q_hat
+            estimated_policy_grad_arr = gaussian_kernel(u) * (reward - q_hat) / pscore
+            estimated_policy_grad_arr /= self.bandwidth
+            estimated_policy_grad_arr += q_hat
 
-        return estimated_policy_value_arr
+        return estimated_policy_grad_arr
 
     def predict(self, context: np.ndarray) -> np.ndarray:
         """Predict best continuous actions for new data.
@@ -642,11 +635,11 @@ class QFuncEstimatorForContinuousAction:
         Number of dimensions of context vectors.
 
     hidden_layer_size: Tuple[int, ...], default = (100,)
-        The i th element specifies the size of the i th layer.
+        The i-th element specifies the size of the i-th layer.
 
     activation: str, default='relu'
         Activation function.
-        Must be one of the following:
+        Must be one of the followings:
         - 'identity', the identity function, :math:`f(x) = x`.
         - 'logistic', the sigmoid function, :math:`f(x) = \\frac{1}{1 + \\exp(x)}`.
         - 'tanh', the hyperbolic tangent function, `:math:f(x) = \\frac{\\exp(x) - \\exp(-x)}{\\exp(x) + \\exp(-x)}`
@@ -654,7 +647,7 @@ class QFuncEstimatorForContinuousAction:
 
     solver: str, default='adam'
         Optimizer of the neural network.
-        Must be one of the following:
+        Must be one of the followings:
         - 'sgd', Stochastic Gradient Descent.
         - 'adam', Adam (Kingma and Ba 2014).
         - 'adagrad', Adagrad (Duchi et al. 2011).
@@ -761,12 +754,12 @@ class QFuncEstimatorForContinuousAction:
             [not isinstance(h, int) or h <= 0 for h in self.hidden_layer_size]
         ):
             raise ValueError(
-                f"hidden_layer_size must be tuple of positive integers, but {self.hidden_layer_size} is given"
+                f"`hidden_layer_size` must be a tuple of positive integers, but {self.hidden_layer_size} is given"
             )
 
         if self.solver not in ("adagrad", "sgd", "adam"):
             raise ValueError(
-                f"solver must be one of 'adam', 'adagrad', or 'sgd', but {self.solver} is given"
+                f"`solver` must be one of 'adam', 'adagrad', or 'sgd', but {self.solver} is given"
             )
 
         check_scalar(self.alpha, "alpha", float, min_val=0.0)
@@ -775,7 +768,7 @@ class QFuncEstimatorForContinuousAction:
             not isinstance(self.batch_size, int) or self.batch_size <= 0
         ):
             raise ValueError(
-                f"batch_size must be a positive integer or 'auto', but {self.batch_size} is given"
+                f"`batch_size` must be a positive integer or 'auto', but {self.batch_size} is given"
             )
 
         check_scalar(self.learning_rate_init, "learning_rate_init", float)
@@ -787,7 +780,7 @@ class QFuncEstimatorForContinuousAction:
         check_scalar(self.max_iter, "max_iter", int, min_val=1)
 
         if not isinstance(self.shuffle, bool):
-            raise ValueError(f"shuffle must be a bool, but {self.shuffle} is given")
+            raise ValueError(f"`shuffle` must be a bool, but {self.shuffle} is given")
 
         check_scalar(self.tol, "tol", float)
         if self.tol <= 0.0:
@@ -797,12 +790,12 @@ class QFuncEstimatorForContinuousAction:
 
         if not isinstance(self.nesterovs_momentum, bool):
             raise ValueError(
-                f"nesterovs_momentum must be a bool, but {self.nesterovs_momentum} is given"
+                f"`nesterovs_momentum` must be a bool, but {self.nesterovs_momentum} is given"
             )
 
         if not isinstance(self.early_stopping, bool):
             raise ValueError(
-                f"early_stopping must be a bool, but {self.early_stopping} is given"
+                f"`early_stopping` must be a bool, but {self.early_stopping} is given"
             )
 
         check_scalar(
@@ -834,7 +827,7 @@ class QFuncEstimatorForContinuousAction:
             activation_layer = nn.ELU
         else:
             raise ValueError(
-                "activation must be one of 'identity', 'logistic', 'tanh', 'relu', or 'elu'"
+                "`activation` must be one of 'identity', 'logistic', 'tanh', 'relu', or 'elu'"
                 f", but {self.activation} is given"
             )
 
@@ -864,7 +857,7 @@ class QFuncEstimatorForContinuousAction:
             Context vectors observed for each data, i.e., :math:`x_i`.
 
         action: array-like, shape (n_rounds,)
-            Continuous action values sampled by a behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
+            Continuous action values sampled by the logging/behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
         reward: array-like, shape (n_rounds,)
             Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
@@ -880,7 +873,7 @@ class QFuncEstimatorForContinuousAction:
         elif isinstance(self.batch_size, int) and self.batch_size > 0:
             batch_size_ = self.batch_size
         else:
-            raise ValueError("batch_size must be a positive integer or 'auto'")
+            raise ValueError("`batch_size` must be a positive integer or 'auto'")
 
         feature = np.c_[context, action[:, np.newaxis]]
         dataset = QFuncEstimatorDatasetForContinuousAction(
@@ -934,7 +927,7 @@ class QFuncEstimatorForContinuousAction:
             Context vectors observed for each data, i.e., :math:`x_i`.
 
         action: array-like, shape (n_rounds,)
-            Continuous action values sampled by a behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
+            Continuous action values sampled by the logging/behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
         reward: array-like, shape (n_rounds,)
             Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
@@ -976,7 +969,7 @@ class QFuncEstimatorForContinuousAction:
             )
         else:
             raise NotImplementedError(
-                "solver must be one of 'adam', 'adagrad', or 'sgd'"
+                "`solver` must be one of 'adam', 'adagrad', or 'sgd'"
             )
 
         (
